# Django Wecom

[![Build and Publish Python Package](https://github.com/liuzihaohao/django_wecom/actions/workflows/release.yml/badge.svg?branch=master)](https://github.com/liuzihaohao/django_wecom/actions/workflows/release.yml)

